==> okteta_15.12.3.orig.tar.xz: okteta-15.12.3/kasten/controllers/view/structures/structviewitemdelegate.h <==
/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2009 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef STRUCTVIEWITEMDELEGATE_H_
#define STRUCTVIEWITEMDELEGATE_H_

#include <QStyledItemDelegate>

class StructViewItemDelegate: public QStyledItemDelegate
{
public:
    StructViewItemDelegate(QObject * parent = 0);
    virtual ~StructViewItemDelegate();
    virtual void setModelData(QWidget * editor, QAbstractItemModel * model,
            const QModelIndex & index) const;
    virtual void setEditorData(QWidget * editor, const QModelIndex & index) const;
    virtual QWidget * createEditor(QWidget * parent,
            const QStyleOptionViewItem & option, const QModelIndex & index) const;
    virtual QSize sizeHint(const QStyleOptionViewItem & option,
            const QModelIndex & index) const;
};

#endif /* STRUCTVIEWITEMDELEGATE_H_ */

==> okteta-16.08.2.tar.xz: okteta-16.08.2/kasten/controllers/view/structures/structviewitemdelegate.h <==
/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2009 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef STRUCTVIEWITEMDELEGATE_H_
#define STRUCTVIEWITEMDELEGATE_H_

#include <QStyledItemDelegate>

class StructViewItemDelegate: public QStyledItemDelegate
{
public:
    explicit StructViewItemDelegate(QObject * parent = 0);
    virtual ~StructViewItemDelegate();
    virtual void setModelData(QWidget * editor, QAbstractItemModel * model,
            const QModelIndex & index) const;
    virtual void setEditorData(QWidget * editor, const QModelIndex & index) const;
    virtual QWidget * createEditor(QWidget * parent,
            const QStyleOptionViewItem & option, const QModelIndex & index) const;
    virtual QSize sizeHint(const QStyleOptionViewItem & option,
            const QModelIndex & index) const;
};

#endif /* STRUCTVIEWITEMDELEGATE_H_ */
